==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/MENUTRANSLATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MENUTRANSLATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="MENUTRANSLATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LANGUAGEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MENUTRANSLATIONID_Type", propOrder = {
    "extmenucode",
    "languageid"
})
public class MENUTRANSLATIONID_Type {

    @XmlElement(name = "EXTMENUCODE", required = true)
    protected String extmenucode;
    @XmlElement(name = "LANGUAGEID", required = true)
    protected LANGUAGEID_Type languageid;

    /**
     * Gets the value of the extmenucode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUCODE() {
        return extmenucode;
    }

    /**
     * Sets the value of the extmenucode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUCODE(String value) {
        this.extmenucode = value;
    }

    /**
     * Gets the value of the languageid property.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getLANGUAGEID() {
        return languageid;
    }

    /**
     * Sets the value of the languageid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setLANGUAGEID(LANGUAGEID_Type value) {
        this.languageid = value;
    }

}

==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/MENUTRANSLATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour MENUTRANSLATIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="MENUTRANSLATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LANGUAGEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MENUTRANSLATIONID_Type", propOrder = {
    "extmenucode",
    "languageid"
})
public class MENUTRANSLATIONID_Type {

    @XmlElement(name = "EXTMENUCODE", required = true)
    protected String extmenucode;
    @XmlElement(name = "LANGUAGEID", required = true)
    protected LANGUAGEID_Type languageid;

    /**
     * Obtient la valeur de la propriété extmenucode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUCODE() {
        return extmenucode;
    }

    /**
     * Définit la valeur de la propriété extmenucode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUCODE(String value) {
        this.extmenucode = value;
    }

    /**
     * Obtient la valeur de la propriété languageid.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getLANGUAGEID() {
        return languageid;
    }

    /**
     * Définit la valeur de la propriété languageid.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setLANGUAGEID(LANGUAGEID_Type value) {
        this.languageid = value;
    }

}
